@@ -35,15 +35,59 @@
 #include "a68g-listing.h"
 
 #if defined (HAVE_MATHLIB)
-#include <Rmath.h>
+  #include <Rmath.h>
 #endif
 
 #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
-#include <windows.h>
+  #include <windows.h>
 #endif
 
 #define WRITE_TXT(fn, txt) ASSERT (write ((fn), (txt), 1 + strlen (txt)) != -1)
 
+#if defined (BUILD_LINUX) && defined (HAVE_EXECINFO_H)
+
+  #include <execinfo.h>
+
+  //! @brief Provide a rudimentary backtrace.
+  
+  void a68g_stack_backtrace (void)
+  {
+  #define DEPTH 16
+    void *array[DEPTH];
+    WRITE_TXT (2, "\n++++ Top of call stack:");
+    size_t size = backtrace (array, DEPTH);
+    if (size > 0) {
+      WRITE_TXT (2, "\n");
+      backtrace_symbols_fd (array, size, 2);
+    }
+  #undef DEPTH
+  }
+  
+  void genie_sigsegv (NODE_T *p)
+  {
+    (void) p;
+    raise (SIGSEGV);
+  }
+  
+  void genie_backtrace (NODE_T *p)
+  {
+    (void) p;
+    a68g_stack_backtrace ();
+  }
+#else
+  void a68g_stack_backtrace (void)
+  {
+    WRITE_TXT (2, "\n++++ Stack backtrace is not available on this platform");
+  }
+  
+  void genie_backtrace (NODE_T *p)
+  {
+    (void) p;
+    a68g_stack_backtrace ();
+  }
+
+#endif
+
 //! @brief Whether x matches c; case insensitive.
 
 BOOL_T match_string (char *x, char *c, char stop)
@@ -71,28 +115,28 @@ BOOL_T match_string (char *x, char *c, char stop)
 
 FILE *a68g_fopen (char *fn, char *mode, char *new_fn)
 {
-#if defined (BUILD_WIN32) || defined (BUILD_WIN64) || !defined (HAVE_DIRENT_H)
-  ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
-  return fopen (new_fn, mode);
-#else
-  errno = 0;
-  BUFFER dn;
-  ASSERT (a68g_bufprt (dn, SNPRINTF_SIZE, "%s/%s", getenv ("HOME"), A68G_DIR) >= 0);
-  int ret = mkdir (dn, (mode_t) (S_IRUSR | S_IWUSR | S_IXUSR));
-  if (ret == 0 || (ret == -1 && errno == EEXIST)) {
-    struct stat status;
-    if (stat (dn, &status) == 0 && S_ISDIR (ST_MODE (&status)) != 0) {
-      FILE *f;
-      ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s/%s", dn, fn) >= 0);
-      f = fopen (new_fn, mode);
-      if (f != NO_FILE) {
-        return f;
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64) || !defined (HAVE_DIRENT_H)
+    ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
+    return fopen (new_fn, mode);
+  #else
+    errno = 0;
+    BUFFER dn;
+    ASSERT (a68g_bufprt (dn, SNPRINTF_SIZE, "%s/%s", getenv ("HOME"), A68G_DIR) >= 0);
+    int ret = mkdir (dn, (mode_t) (S_IRUSR | S_IWUSR | S_IXUSR));
+    if (ret == 0 || (ret == -1 && errno == EEXIST)) {
+      struct stat status;
+      if (stat (dn, &status) == 0 && S_ISDIR (ST_MODE (&status)) != 0) {
+        FILE *f;
+        ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s/%s", dn, fn) >= 0);
+        f = fopen (new_fn, mode);
+        if (f != NO_FILE) {
+          return f;
+        }
       }
     }
-  }
-  ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
-  return fopen (new_fn, mode);
-#endif
+    ASSERT (a68g_bufprt (new_fn, SNPRINTF_SIZE, "%s", fn) >= 0);
+    return fopen (new_fn, mode);
+  #endif
 }
 
 //! @brief Get terminal size.
@@ -102,37 +146,37 @@ void a68g_getty (int *h, int *c)
 // Default action first.
   (*h) = MAX_TERM_HEIGTH;
   (*c) = MAX_TERM_WIDTH;
-#if (defined (HAVE_SYS_IOCTL_H) && defined (TIOCGWINSZ))
-  {
-    struct winsize w;
-    if (ioctl (0, TIOCGWINSZ, &w) == 0) {
-      (*h) = w.ws_row;
-      (*c) = w.ws_col;
+  #if (defined (HAVE_SYS_IOCTL_H) && defined (TIOCGWINSZ))
+    {
+      struct winsize w;
+      if (ioctl (0, TIOCGWINSZ, &w) == 0) {
+        (*h) = w.ws_row;
+        (*c) = w.ws_col;
+      }
     }
-  }
-#elif (defined (HAVE_SYS_IOCTL_H) && defined (TIOCGSIZE))
-  {
-    struct ttysize w;
-    (void) ioctl (0, TIOCGSIZE, &w);
-    if (w.ts_lines > 0) {
-      (*h) = w.ts_lines;
+  #elif (defined (HAVE_SYS_IOCTL_H) && defined (TIOCGSIZE))
+    {
+      struct ttysize w;
+      (void) ioctl (0, TIOCGSIZE, &w);
+      if (w.ts_lines > 0) {
+        (*h) = w.ts_lines;
+      }
+      if (w.ts_cols > 0) {
+        (*c) = w.ts_cols;
+      }
     }
-    if (w.ts_cols > 0) {
-      (*c) = w.ts_cols;
+  #elif (defined (HAVE_SYS_IOCTL_H) && defined (WIOCGETD))
+    {
+      struct uwdata w;
+      (void) ioctl (0, WIOCGETD, &w);
+      if (w.uw_heigth > 0 && w.uw_vs != 0) {
+        (*h) = w.uw_heigth / w.uw_vs;
+      }
+      if (w.uw_width > 0 && w.uw_hs != 0) {
+        (*c) = w.uw_width / w.uw_hs;
+      }
     }
-  }
-#elif (defined (HAVE_SYS_IOCTL_H) && defined (WIOCGETD))
-  {
-    struct uwdata w;
-    (void) ioctl (0, WIOCGETD, &w);
-    if (w.uw_heigth > 0 && w.uw_vs != 0) {
-      (*h) = w.uw_heigth / w.uw_vs;
-    }
-    if (w.uw_width > 0 && w.uw_hs != 0) {
-      (*c) = w.uw_width / w.uw_hs;
-    }
-  }
-#endif
+  #endif
 }
 
 // Signal handlers.
@@ -144,9 +188,10 @@ void a68g_getty (int *h, int *c)
 void sigwinch_handler (int i)
 {
   (void) i;
-  ABEND (signal (SIGWINCH, sigwinch_handler) == SIG_ERR, ERROR_ACTION, __func__);
+  ABEND (signal (SIGWINCH, sigwinch_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
   a68g_getty (&A68G (term_heigth), &A68G (term_width));
 }
+
 #endif
 
 //! @brief Signal handler for segment violation.
@@ -161,8 +206,9 @@ void sigsegv_handler (int i)
     WRITE_TXT (2, FILE_INITIAL_NAME (&A68G_JOB));
   }
   WRITE_TXT (2, ": memory access violation\n");
-  extern void stack_backtrace (void);
-  stack_backtrace ();
+  #if defined (BUILD_LINUX) && defined (HAVE_EXECINFO_H)
+    a68g_stack_backtrace ();
+  #endif
   exit (EXIT_FAILURE);
 }
 
@@ -171,7 +217,7 @@ void sigsegv_handler (int i)
 void sigint_handler (int i)
 {
   (void) i;
-  ABEND (signal (SIGINT, sigint_handler) == SIG_ERR, ERROR_ACTION, __func__);
+  ABEND (signal (SIGINT, sigint_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
   if (!(STATUS_TEST (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK) || A68G (in_monitor))) {
     STATUS_SET (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK);
     genie_break (TOP_NODE (&A68G_JOB));
@@ -185,7 +231,7 @@ void sigint_handler (int i)
 void sigttin_handler (int i)
 {
   (void) i;
-  ABEND (A68G_TRUE, ERROR_ACTION, __func__);
+  ABEND (A68G_TRUE, ERROR_ACTION, NO_TEXT);
 }
 
 //! @brief Signal broken pipe.
@@ -193,7 +239,7 @@ void sigttin_handler (int i)
 void sigpipe_handler (int i)
 {
   (void) i;
-  ABEND (A68G_TRUE, ERROR_ACTION, __func__);
+  ABEND (A68G_TRUE, ERROR_ACTION, NO_TEXT);
 }
 
 //! @brief Signal alarm - time limit check.
@@ -222,7 +268,7 @@ void sigalrm_handler (int i)
       exit_genie ((NODE_T *) A68G (f_entry), A68G_RUNTIME_ERROR);
     }
   }
-  ABEND (signal (SIGALRM, sigalrm_handler) == SIG_ERR, ERROR_ACTION, __func__);
+  ABEND (signal (SIGALRM, sigalrm_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
   (void) a68g_alarm (INTERRUPT_INTERVAL);
 }
 
@@ -232,29 +278,29 @@ void sigalrm_handler (int i)
 
 void install_signal_handlers (void)
 {
-  ABEND (signal (SIGINT, sigint_handler) == SIG_ERR, ERROR_ACTION, __func__);
-  ABEND (signal (SIGSEGV, sigsegv_handler) == SIG_ERR, ERROR_ACTION, __func__);
-#if defined (SIGWINCH)
-  ABEND (signal (SIGWINCH, sigwinch_handler) == SIG_ERR, ERROR_ACTION, __func__);
-#endif
-#if defined (BUILD_UNIX)
-  ABEND (signal (SIGALRM, sigalrm_handler) == SIG_ERR, ERROR_ACTION, __func__);
-  ABEND (signal (SIGPIPE, sigpipe_handler) == SIG_ERR, ERROR_ACTION, __func__);
-  ABEND (signal (SIGTTIN, sigttin_handler) == SIG_ERR, ERROR_ACTION, __func__);
-#endif
+  ABEND (signal (SIGINT, sigint_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
+  ABEND (signal (SIGSEGV, sigsegv_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
+  #if defined (SIGWINCH)
+    ABEND (signal (SIGWINCH, sigwinch_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
+  #endif
+  #if defined (BUILD_UNIX)
+    ABEND (signal (SIGALRM, sigalrm_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
+    ABEND (signal (SIGPIPE, sigpipe_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
+    ABEND (signal (SIGTTIN, sigttin_handler) == SIG_ERR, ERROR_ACTION, NO_TEXT);
+  #endif
 }
 
 //! @brief Wall clock versus arbitrary origin.
 
 REAL_T wall_seconds (void)
 {
-#if defined (HAVE_RTLIB)
-  struct timespec ts;
-  clock_gettime (CLOCK_MONOTONIC, &ts);
-  return ts.tv_sec + ts.tv_nsec * 1e-9; 
-#else
-  return seconds();
-#endif
+  #if defined (HAVE_RTLIB)
+    struct timespec ts;
+    clock_gettime (CLOCK_MONOTONIC, &ts);
+    return ts.tv_sec + ts.tv_nsec * 1e-9; 
+  #else
+    return seconds();
+  #endif
 } 
 
 //! @brief Process time versus arbitrary origin.
@@ -264,22 +310,20 @@ REAL_T seconds (void)
   return (REAL_T) clock () / (REAL_T) CLOCKS_PER_SEC;
 }
 
-
-
 //! @brief Delay for specified number of microseconds.
 
 int a68g_usleep (unsigned delay)
 {
-#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
-  errno = ENOSYS; // Function not implemented.
-  return -1; 
-#else
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+    errno = ENOSYS; // Function not implemented.
+    return -1; 
+  #else
 // usleep is not compatible with _XOPEN_SOURCE 700.
-  struct timespec reqtime;
-  reqtime.tv_sec = delay / 1000000;
-  reqtime.tv_nsec = 1000 * (delay % 1000000);
-  return nanosleep (&reqtime, NULL);
-#endif
+    struct timespec reqtime;
+    reqtime.tv_sec = delay / 1000000;
+    reqtime.tv_nsec = 1000 * (delay % 1000000);
+    return nanosleep (&reqtime, NULL);
+  #endif
 }
 
 //! @brief Safely set buffer.
@@ -368,48 +412,3 @@ int a68g_bufprt (char *dst, size_t len, const char *format, ...)
   }
 }
 
-#if defined (BUILD_LINUX) && defined (HAVE_EXECINFO_H)
-
-#include <execinfo.h>
-
-void genie_sigsegv (NODE_T *p)
-{
-  (void) p;
-  raise (SIGSEGV);
-}
-
-//! @brief Provide a rudimentary backtrace.
-
-void stack_backtrace (void)
-{
-#define DEPTH 16
-  void *array[DEPTH];
-  WRITE_TXT (2, "\n++++ Top of call stack:");
-  size_t size = backtrace (array, DEPTH);
-  if (size > 0) {
-    WRITE_TXT (2, "\n");
-    backtrace_symbols_fd (array, size, 2);
-  }
-#undef DEPTH
-}
-
-void genie_backtrace (NODE_T *p)
-{
-  (void) p;
-  stack_backtrace ();
-}
-
-#else
-
-void stack_backtrace (void)
-{
-  WRITE_TXT (2, "\n++++ Stack backtrace is not available on this platform");
-}
-
-void genie_backtrace (NODE_T *p)
-{
-  (void) p;
-  stack_backtrace ();
-}
-#endif
-
