@@ -115,26 +115,28 @@ void pretty_diag (FILE_T f, char *p)
 
 //! @brief Abnormal end.
 
-void abend (char *reason, char *info, char *file, int line)
+void abend (char *reason, char *info, char *func)
 {
-#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
-  printf_s ("%s: abend: %s.\n", A68G (a68g_cmd_name), reason);
-  exit (EXIT_FAILURE);
-#else
-  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: exiting: %s (%s: %d", A68G (a68g_cmd_name), reason, basename (file), line) >= 0);
-  if (info != NO_TEXT) {
-    a68g_bufcat (A68G (output_line), ", ", BUFFER_SIZE);
-    a68g_bufcat (A68G (output_line), info, BUFFER_SIZE);
-  }
-  if (errno != 0) {
-    a68g_bufcat (A68G (output_line), ", ", BUFFER_SIZE);
-    a68g_bufcat (A68G (output_line), error_specification (), BUFFER_SIZE);
-  }
-  a68g_bufcat (A68G (output_line), ")\n", BUFFER_SIZE);
-  io_close_tty_line ();
-  pretty_diag (A68G_STDERR, A68G (output_line));
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+    printf_s ("%s: abend: %s.\n", A68G (a68g_cmd_name), reason);
+  #else
+    if (func == NO_TEXT) {
+      if (info == NO_TEXT) {
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: abend: %s.", A68G (a68g_cmd_name), reason) >= 0);
+      } else {
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: abend: %s (%s).", A68G (a68g_cmd_name), reason, info) >= 0);
+      }
+    } else {
+      if (info == NO_TEXT) {
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: abend: %s (%s).", A68G (a68g_cmd_name), reason, func) >= 0);
+      } else {
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: abend: %s (%s, %s).", A68G (a68g_cmd_name), reason, info, func) >= 0);
+      }
+    }
+    io_close_tty_line ();
+    pretty_diag (A68G_STDERR, A68G (output_line));
+  #endif
   a68g_exit (EXIT_FAILURE);
-#endif
 }
 
 //! @brief Position in line .
@@ -408,7 +410,7 @@ void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
   if (info != NO_TEXT) {
     size_t len = strlen (txt) + 3;
     char *txti = a68g_alloc(len, __FILE__, __LINE__);
-    ABEND (txti == NO_TEXT, ERROR_MEMORY_FULL, __func__);
+    ABEND (txti == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
     a68g_bufcpy (txti, txt, len);
     a68g_bufcat (txti, " Z", len);
     if (errno != 0) {
@@ -730,7 +732,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
           } else if (t[0] == 'L') {
             LINE_T *a = va_arg (args, LINE_T *);
             char d[SMALL_BUFFER_SIZE];
-            ABEND (a == NO_LINE, ERROR_INTERNAL_CONSISTENCY, __func__);
+            ABEND (a == NO_LINE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
             if (NUMBER (a) == 0) {
               a68g_bufcat (b, "in standard environment", BUFFER_SIZE);
             } else {
