@@ -28,7 +28,7 @@
 #include "a68g-genie.h"
 
 #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
-#include <windows.h>
+  #include <windows.h>
 #endif
 
 //! @brief Safely get dir name from path.
@@ -38,8 +38,8 @@ char *a68g_dirname (char *src)
   size_t len = strlen (src) + 1;
   char *cpy = (char *) get_fixed_heap_space (len + 1);
   char *dst = (char *) get_fixed_heap_space (len + 1);
-  ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, __func__);
-  ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, __func__);
+  ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
+  ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   a68g_bufcpy (cpy, src, len);
   a68g_bufcpy (dst, dirname (cpy), len);
   return dst;
@@ -52,8 +52,8 @@ char *a68g_basename (char *src)
   size_t len = strlen (src) + 1;
   char *cpy = (char *) get_fixed_heap_space (len + 1);
   char *dst = (char *) get_fixed_heap_space (len + 1);
-  ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, __func__);
-  ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, __func__);
+  ABEND (cpy == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
+  ABEND (dst == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   a68g_bufcpy (cpy, src, len);
   a68g_bufcpy (dst, basename (cpy), len);
   return dst;
@@ -113,44 +113,44 @@ char *a68g_relpath (char *p1, char *p2, char *fn)
   ASSERT (p1 != NO_TEXT);
   ASSERT (p2 != NO_TEXT);
   ASSERT (fn != NO_TEXT);
-#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
-  if (p2[0] == '\\') {
-    a68g_bufcpy (q, p2, PATH_MAX);
-  } else {
-    a68g_bufcpy (q, p1, PATH_MAX);
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+    if (p2[0] == '\\') {
+      a68g_bufcpy (q, p2, PATH_MAX);
+    } else {
+      a68g_bufcpy (q, p1, PATH_MAX);
+      a68g_bufcat (q, "\\", PATH_MAX);
+      a68g_bufcat (q, p2, PATH_MAX);
+    }
     a68g_bufcat (q, "\\", PATH_MAX);
-    a68g_bufcat (q, p2, PATH_MAX);
-  }
-  a68g_bufcat (q, "\\", PATH_MAX);
-  a68g_bufcat (q, fn, PATH_MAX);
-#else
-  if (p2[0] == '/') {
+    a68g_bufcat (q, fn, PATH_MAX);
+  #else
+    if (p2[0] == '/') {
 // Absolute path starting at root.
-    a68g_bufcpy (q, p2, PATH_MAX);
-  } else if (p2[0] == '~') {
-// "~" is a shell extension, not Unix.
-// We handle it anyway, as a courtesy.
-    a68g_bufcpy (q, getenv("HOME"), PATH_MAX);
-    a68g_bufcat (q, &p2[1], PATH_MAX);
-  } else {
-    a68g_bufcpy (q, p1, PATH_MAX);
+      a68g_bufcpy (q, p2, PATH_MAX);
+    } else if (p2[0] == '~') {
+      // "~" is a shell extension, not Unix.
+      // We handle it anyway, as a courtesy.
+      a68g_bufcpy (q, getenv("HOME"), PATH_MAX);
+      a68g_bufcat (q, &p2[1], PATH_MAX);
+    } else {
+      a68g_bufcpy (q, p1, PATH_MAX);
+      a68g_bufcat (q, "/", PATH_MAX);
+      a68g_bufcat (q, p2, PATH_MAX);
+    }
     a68g_bufcat (q, "/", PATH_MAX);
-    a68g_bufcat (q, p2, PATH_MAX);
-  }
-  a68g_bufcat (q, "/", PATH_MAX);
-  a68g_bufcat (q, fn, PATH_MAX);
-#endif
+    a68g_bufcat (q, fn, PATH_MAX);
+  #endif
 // Error handling in the caller!
   errno = 0;
-#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
-  char *r = win32_realpath (q, NO_TEXT);
-#else
-  char *r = realpath (q, NO_TEXT);
-#endif
+  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+    char *r = win32_realpath (q, NO_TEXT);
+  #else
+    char *r = realpath (q, NO_TEXT);
+  #endif
   if (r != NO_TEXT) {
     size_t len = strlen (r) + 1;
     char *rc = (char *) get_fixed_heap_space (len);
-    ABEND (rc == NO_TEXT, ERROR_MEMORY_FULL, __func__);
+    ABEND (rc == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
     a68g_bufcpy (rc, r, len);
     free (r);
     return rc;
@@ -170,11 +170,11 @@ void genie_realpath (NODE_T * p)
     PUSH_REF (p, empty_string (p));
   } else {
 // Note that ~ is not resolved since that is the shell, not libc.
-#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
-    char *out = win32_realpath (in, NO_TEXT);
-#else
-    char *out = realpath (in, NO_TEXT);
-#endif
+    #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+      char *out = win32_realpath (in, NO_TEXT);
+    #else
+      char *out = realpath (in, NO_TEXT);
+    #endif
     if (out == NO_TEXT) {
       PUSH_REF (p, empty_string (p));
     } else {
