@@ -287,8 +287,8 @@ BOOL_T strip_extension (char *ext)
 
 void open_with_extensions (void)
 {
-  FILE_SOURCE_FD (&A68G_JOB) = -1;
-  for (int k = 0; k < EXTENSIONS && FILE_SOURCE_FD (&A68G_JOB) == -1; k++) {
+  FILE_SOURCE_FD (&A68G_JOB) = A68G_NO_FILE;
+  for (int k = 0; k < EXTENSIONS && FILE_SOURCE_FD (&A68G_JOB) == A68G_NO_FILE; k++) {
     size_t len;
     char *fn = NULL;
     if (extensions[k] == NO_TEXT) {
@@ -302,7 +302,7 @@ void open_with_extensions (void)
       a68g_bufcat (fn, extensions[k], len);
     }
     FILE_SOURCE_FD (&A68G_JOB) = open (fn, O_RDONLY | O_BINARY);
-    if (FILE_SOURCE_FD (&A68G_JOB) != -1) {
+    if (FILE_SOURCE_FD (&A68G_JOB) != A68G_NO_FILE) {
       BOOL_T cont = A68G_TRUE;
       a68g_free (FILE_SOURCE_NAME (&A68G_JOB));
       a68g_free (FILE_GENERIC_NAME (&A68G_JOB));
@@ -400,11 +400,11 @@ void compiler_interpreter (void)
     SCAN_ERROR (S_ISDIR (path_stat.st_mode), NO_LINE, NO_TEXT, ERROR_IS_DIRECTORY);
     SCAN_ERROR (!S_ISREG (path_stat.st_mode), NO_LINE, NO_TEXT, ERROR_NO_REGULAR_FILE);
   }
-  if (FILE_SOURCE_FD (&A68G_JOB) == -1) {
+  if (FILE_SOURCE_FD (&A68G_JOB) == A68G_NO_FILE) {
     scan_error (NO_LINE, NO_TEXT, ERROR_SOURCE_FILE_OPEN);
   }
-  ABEND (FILE_SOURCE_NAME (&A68G_JOB) == NO_TEXT, ERROR_INTERNAL_CONSISTENCY, __func__);
-  ABEND (FILE_GENERIC_NAME (&A68G_JOB) == NO_TEXT, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (FILE_SOURCE_NAME (&A68G_JOB) == NO_TEXT, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
+  ABEND (FILE_GENERIC_NAME (&A68G_JOB) == NO_TEXT, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
 // Object file.
   size_t len = 1 + strlen (FILE_GENERIC_NAME (&A68G_JOB)) + strlen (OBJECT_EXTENSION);
   FILE_OBJECT_NAME (&A68G_JOB) = (char *) get_heap_space (len);
@@ -496,15 +496,15 @@ void compiler_interpreter (void)
       genie ((void *) NULL);
     #endif
 // Free heap allocated by genie.
-    if (A68G_GC (total) > 10 * MEGABYTE) {
+    if (A68G_GC (total) > 10 * A68G_MEGA) {
       ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, 
         "sweeps=" A68G_LU ", refused=" A68G_LU ", freed=" A68G_LU "MB",  
-        A68G_GC (sweeps), A68G_GC (refused), A68G_GC (total) / MEGABYTE)
+        A68G_GC (sweeps), A68G_GC (refused), A68G_GC (total) / A68G_MEGA)
       );
-    } else if (A68G_GC (total) > 10 * KILOBYTE) {
+    } else if (A68G_GC (total) > 10 * A68G_KILO) {
       ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, 
         "sweeps=" A68G_LU ", refused=" A68G_LU ", freed=" A68G_LU "kB",  
-        A68G_GC (sweeps), A68G_GC (refused), A68G_GC (total) / KILOBYTE)
+        A68G_GC (sweeps), A68G_GC (refused), A68G_GC (total) / A68G_KILO)
       );
     } else {
       ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, 
@@ -529,7 +529,7 @@ void compiler_interpreter (void)
   announce_phase ("write listing");
   if (OPTION_MOID_LISTING (&A68G_JOB) || OPTION_TREE_LISTING (&A68G_JOB) || OPTION_SOURCE_LISTING (&A68G_JOB) || OPTION_OBJECT_LISTING (&A68G_JOB) || OPTION_STATISTICS_LISTING (&A68G_JOB)) {
     FILE_LISTING_FD (&A68G_JOB) = open (FILE_LISTING_NAME (&A68G_JOB), O_WRONLY | O_CREAT | O_TRUNC, A68G_PROTECTION);
-    ABEND (FILE_LISTING_FD (&A68G_JOB) == -1, ERROR_ACTION, __func__);
+    ABEND (FILE_LISTING_FD (&A68G_JOB) == A68G_NO_FILE, ERROR_ACTION, NO_TEXT);
     FILE_LISTING_OPENED (&A68G_JOB) = A68G_TRUE;
   } else {
     FILE_LISTING_OPENED (&A68G_JOB) = A68G_FALSE;
@@ -582,29 +582,28 @@ void a68g_exit (int code)
 // Clean up stale things.
   free_syntax_tree (TOP_NODE (&A68G_JOB));
   free_option_list (OPTION_LIST (&A68G_JOB));
-  a68g_free (A68G (node_register));
-  a68g_free (A68G (options));
-  discard_heap ();
-  a68g_free (FILE_PATH (&A68G_JOB));
-  a68g_free (FILE_INITIAL_NAME (&A68G_JOB));
-  a68g_free (FILE_GENERIC_NAME (&A68G_JOB));
-  a68g_free (FILE_SOURCE_NAME (&A68G_JOB));
-  a68g_free (FILE_LISTING_NAME (&A68G_JOB));
-  a68g_free (FILE_OBJECT_NAME (&A68G_JOB));
-  a68g_free (FILE_PLUGIN_NAME (&A68G_JOB));
-  a68g_free (FILE_BINARY_NAME (&A68G_JOB));
-  a68g_free (FILE_PRETTY_NAME (&A68G_JOB));
-  a68g_free (FILE_SCRIPT_NAME (&A68G_JOB));
-  a68g_free (FILE_DIAGS_NAME (&A68G_JOB));
+  a68g_free (A68G_MP (mp_180_over_pi));
+  a68g_free (A68G_MP (mp_half_pi));
+  a68g_free (A68G_MP (mp_ln_pi));
   a68g_free (A68G_MP (mp_one));
   a68g_free (A68G_MP (mp_pi));
-  a68g_free (A68G_MP (mp_half_pi));
-  a68g_free (A68G_MP (mp_two_pi));
-  a68g_free (A68G_MP (mp_sqrt_two_pi));
-  a68g_free (A68G_MP (mp_sqrt_pi));
-  a68g_free (A68G_MP (mp_ln_pi));
-  a68g_free (A68G_MP (mp_180_over_pi));
   a68g_free (A68G_MP (mp_pi_over_180));
+  a68g_free (A68G_MP (mp_sqrt_pi));
+  a68g_free (A68G_MP (mp_sqrt_two_pi));
+  a68g_free (A68G_MP (mp_two_pi));
+  a68g_free (A68G (node_register));
+  a68g_free (A68G (options));
+  a68g_free (FILE_BINARY_NAME (&A68G_JOB));
+  a68g_free (FILE_DIAGS_NAME (&A68G_JOB));
+  a68g_free (FILE_GENERIC_NAME (&A68G_JOB));
+  a68g_free (FILE_INITIAL_NAME (&A68G_JOB));
+  a68g_free (FILE_LISTING_NAME (&A68G_JOB));
+  a68g_free (FILE_OBJECT_NAME (&A68G_JOB));
+  a68g_free (FILE_PATH (&A68G_JOB));
+  a68g_free (FILE_PLUGIN_NAME (&A68G_JOB));
+  a68g_free (FILE_PRETTY_NAME (&A68G_JOB));
+  a68g_free (FILE_SCRIPT_NAME (&A68G_JOB));
+  a68g_free (FILE_SOURCE_NAME (&A68G_JOB));
   exit (code);
 }
 
@@ -612,11 +611,14 @@ void a68g_exit (int code)
 
 int main (int argc, char *argv[])
 {
-  BYTE_T stack_offset;          // Leave this here!
+  BYTE_T stack_offset;            // Leave this here!
+  #if defined (MALLOPT)
+    mallopt (M_CHECK_ACTION, 3);  // Default in recent glibc.
+  #endif
   A68G (argc) = argc;
   A68G (argv) = argv;
   A68G (close_tty_on_exit) = A68G_TRUE;
-  FILE_DIAGS_FD (&A68G_JOB) = -1;
+  FILE_DIAGS_FD (&A68G_JOB) = A68G_NO_FILE;
 // Get command name and discard path.
   #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
     a68g_bufcpy (A68G (a68g_cmd_name), "a68g", BUFFER_SIZE);
@@ -658,7 +660,7 @@ int main (int argc, char *argv[])
     A68G_STACK = NO_BYTE;
     A68G_HEAP = NO_BYTE;
     A68G_HANDLES = NO_BYTE;
-    get_stack_size ();
+    get_C_stack_size ();
 // Well, let's start.
     TOP_REFINEMENT (&A68G_JOB) = NO_REFINEMENT;
     FILE_INITIAL_NAME (&A68G_JOB) = NO_TEXT;
