@@ -543,6 +543,7 @@ void set_up_file (NODE_T * p, A68G_REF * z, int fd, A68G_CHANNEL chan, BOOL_T r_
   FD (f) = fd;
   STREAM (&DEVICE (f)) = NO_STREAM;
   OPENED (f) = A68G_TRUE;
+  APPEND (f) = A68G_FALSE;
   OPEN_EXCLUSIVE (f) = A68G_FALSE;
   READ_MOOD (f) = r_mood;
   WRITE_MOOD (f) = w_mood;
@@ -649,7 +650,7 @@ void genie_exec_sub (NODE_T * p)
     if (pid == -1) {
       PUSH_VALUE (p, -1, A68G_INT);
     } else if (pid == 0) {
-  // Child process.
+// Child process.
       char *prog = (char *) get_heap_space (1 + a68g_string_size (p, a_prog));
       ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
       char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
@@ -660,11 +661,11 @@ void genie_exec_sub (NODE_T * p)
         exit_genie (p, A68G_RUNTIME_ERROR);
       }
       (void) execve (prog, argv, envp);
-  // execve only returns if it fails - end child process.
+// execve only returns if it fails - end child process.
       a68g_exit (EXIT_FAILURE);
       PUSH_VALUE (p, 0, A68G_INT);
     } else {
-  // parent process.
+// parent process.
       PUSH_VALUE (p, pid, A68G_INT);
     }
   #endif
@@ -690,46 +691,46 @@ void genie_exec_sub_pipeline (NODE_T * p)
   #if !defined (BUILD_UNIX)
     int pid = -1;
     (void) pid;
-    genie_mkpipe (p, -1, -1, -1);
+    genie_mkpipe (p, A68G_NO_FILE, A68G_NO_FILE, -1);
     return;
   #else
-  // Create the pipes and fork.
+// Create the pipes and fork.
     int ptoc_fd[2], ctop_fd[2];
     if ((pipe (ptoc_fd) == -1) || (pipe (ctop_fd) == -1)) {
-      genie_mkpipe (p, -1, -1, -1);
+      genie_mkpipe (p, A68G_NO_FILE, A68G_NO_FILE, -1);
       return;
     }
     int pid = (int) fork ();
     if (pid == -1) {
-  // Fork failure.
-      genie_mkpipe (p, -1, -1, -1);
+// Fork failure.
+      genie_mkpipe (p, A68G_NO_FILE, A68G_NO_FILE, -1);
       return;
     }
     if (pid == 0) {
-  // Child process.
-  // Convert  strings.
+// Child process.
+// Convert  strings.
       char *prog = (char *) get_heap_space (1 + a68g_string_size (p, a_prog));
       ASSERT (a_to_c_string (p, prog, a_prog) != NO_TEXT);
       char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
       convert_string_vector (p, argv, a_args);
       convert_string_vector (p, envp, a_env);
-  // Set up redirection.
+// Set up redirection.
       ASSERT (close (ctop_fd[FD_READ]) == 0);
       ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
       ASSERT (close (A68G_STDIN) == 0);
       ASSERT (close (A68G_STDOUT) == 0);
-      ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
-      ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
+      ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != A68G_NO_FILE);
+      ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != A68G_NO_FILE);
       if (argv[0] == NO_TEXT) {
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
         exit_genie (p, A68G_RUNTIME_ERROR);
       }
       (void) execve (prog, argv, envp);
-  // execve only returns if it fails - end child process.
+// execve only returns if it fails - end child process.
       a68g_exit (EXIT_FAILURE);
-      genie_mkpipe (p, -1, -1, -1);
+      genie_mkpipe (p, A68G_NO_FILE, A68G_NO_FILE, -1);
     } else {
-  // Parent process.
+// Parent process.
       ASSERT (close (ptoc_fd[FD_READ]) == 0);
       ASSERT (close (ctop_fd[FD_WRITE]) == 0);
       genie_mkpipe (p, ctop_fd[FD_READ], ptoc_fd[FD_WRITE], pid);
@@ -760,15 +761,15 @@ void genie_exec_sub_output (NODE_T * p)
     PUSH_VALUE (p, -1, A68G_INT);
     return;
   #else
-  // Create the pipes and fork.
+// Create the pipes and fork.
     int ptoc_fd[2], ctop_fd[2];
-    if ((pipe (ptoc_fd) == -1) || (pipe (ctop_fd) == -1)) {
+    if ((pipe (ptoc_fd) == A68G_NO_FILE) || (pipe (ctop_fd) == A68G_NO_FILE)) {
       PUSH_VALUE (p, -1, A68G_INT);
       return;
     }
     int pid = (int) fork ();
     if (pid == -1) {
-  // Fork failure.
+// Fork failure.
       PUSH_VALUE (p, -1, A68G_INT);
       return;
     }
@@ -778,23 +779,23 @@ void genie_exec_sub_output (NODE_T * p)
       char *argv[VECTOR_SIZE], *envp[VECTOR_SIZE];
       convert_string_vector (p, argv, a_args);
       convert_string_vector (p, envp, a_env);
-  // Set up redirection.
+// Set up redirection.
       ASSERT (close (ctop_fd[FD_READ]) == 0);
       ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
       ASSERT (close (A68G_STDIN) == 0);
       ASSERT (close (A68G_STDOUT) == 0);
-      ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
-      ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
+      ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != A68G_NO_FILE);
+      ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != A68G_NO_FILE);
       if (argv[0] == NO_TEXT) {
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
         exit_genie (p, A68G_RUNTIME_ERROR);
       }
       (void) execve (prog, argv, envp);
-  // execve only returns if it fails - end child process.
+// execve only returns if it fails - end child process.
       a68g_exit (EXIT_FAILURE);
       PUSH_VALUE (p, -1, A68G_INT);
     } else {
-  // Parent process.
+// Parent process.
       char ch;
       ASSERT (close (ptoc_fd[FD_READ]) == 0);
       ASSERT (close (ctop_fd[FD_WRITE]) == 0);
