@@ -87,9 +87,9 @@ void change_gc_masks (NODE_T * p, BOOL_T set)
 
 void exit_genie (NODE_T * p, int ret)
 {
-#if defined (HAVE_CURSES)
-  genie_curses_end (p);
-#endif
+  #if defined (HAVE_CURSES)
+    genie_curses_end (p);
+  #endif
   A68G (close_tty_on_exit) = A68G_TRUE;
   if (!A68G (in_execution)) {
     return;
@@ -107,21 +107,21 @@ void exit_genie (NODE_T * p, int ret)
     if ((ret & A68G_FORCE_QUIT) != NULL_MASK) {
       ret &= ~A68G_FORCE_QUIT;
     }
-#if defined (BUILD_PARALLEL_CLAUSE)
-    if (!is_main_thread ()) {
-      genie_set_exit_from_threads (ret);
-    } else {
+    #if defined (BUILD_PARALLEL_CLAUSE)
+      if (!is_main_thread ()) {
+        genie_set_exit_from_threads (ret);
+      } else {
+        A68G (in_execution) = A68G_FALSE;
+        A68G (ret_line_number) = LINE_NUMBER (p);
+        A68G (ret_code) = ret;
+        longjmp (A68G (genie_exit_label), 1);
+      }
+    #else
       A68G (in_execution) = A68G_FALSE;
       A68G (ret_line_number) = LINE_NUMBER (p);
       A68G (ret_code) = ret;
       longjmp (A68G (genie_exit_label), 1);
-    }
-#else
-    A68G (in_execution) = A68G_FALSE;
-    A68G (ret_line_number) = LINE_NUMBER (p);
-    A68G (ret_code) = ret;
-    longjmp (A68G (genie_exit_label), 1);
-#endif
+    #endif
   }
 }
 
@@ -246,10 +246,10 @@ int mode_attribute (MOID_T * p)
 
 void genie_preprocess (NODE_T * p, int *max_lev, void *compile_plugin)
 {
-#if defined (BUILD_A68G_COMPILER)
-  static char *last_compile_name = NO_TEXT;
-  static PROP_PROC *last_compile_unit = NO_PPROC;
-#endif
+  #if defined (BUILD_A68G_COMPILER)
+    static char *last_compile_name = NO_TEXT;
+    static PROP_PROC *last_compile_unit = NO_PPROC;
+  #endif
   for (; p != NO_NODE; FORWARD (p)) {
     if (STATUS_TEST (p, BREAKPOINT_MASK)) {
       if (!(STATUS_TEST (p, INTERRUPTIBLE_MASK))) {
@@ -262,21 +262,21 @@ void genie_preprocess (NODE_T * p, int *max_lev, void *compile_plugin)
 // The default.
       UNIT (&GPROP (p)) = genie_unit;
       SOURCE (&GPROP (p)) = p;
-#if defined (BUILD_A68G_COMPILER)
-      if (OPTION_OPT_LEVEL (&A68G_JOB) > 0 && COMPILE_NAME (GINFO (p)) != NO_TEXT && compile_plugin != NULL) {
-        if (COMPILE_NAME (GINFO (p)) == last_compile_name) {
-// We copy.
-          UNIT (&GPROP (p)) = last_compile_unit;
-        } else {
-// We look up.
-// Next line may provoke a warning even with this POSIX workaround. Tant pis.
-          *(void **) &(UNIT (&GPROP (p))) = dlsym (compile_plugin, COMPILE_NAME (GINFO (p)));
-          ABEND (UNIT (&GPROP (p)) == NULL, ERROR_INTERNAL_CONSISTENCY, dlerror ());
-          last_compile_name = COMPILE_NAME (GINFO (p));
-          last_compile_unit = UNIT (&GPROP (p));
+      #if defined (BUILD_A68G_COMPILER)
+        if (OPTION_OPT_LEVEL (&A68G_JOB) > 0 && COMPILE_NAME (GINFO (p)) != NO_TEXT && compile_plugin != NULL) {
+          if (COMPILE_NAME (GINFO (p)) == last_compile_name) {
+            // We copy.
+            UNIT (&GPROP (p)) = last_compile_unit;
+          } else {
+            // We look up.
+            // Next line may provoke a warning even with this POSIX workaround. Tant pis.
+            *(void **) &(UNIT (&GPROP (p))) = dlsym (compile_plugin, COMPILE_NAME (GINFO (p)));
+            ABEND (UNIT (&GPROP (p)) == NULL, ERROR_INTERNAL_CONSISTENCY, dlerror ());
+            last_compile_name = COMPILE_NAME (GINFO (p));
+            last_compile_unit = UNIT (&GPROP (p));
+          }
         }
-      }
-#endif
+      #endif
     }
     if (MOID (p) != NO_MOID) {
       SIZE (MOID (p)) = moid_size (MOID (p));
@@ -370,15 +370,15 @@ void genie (void *compile_plugin)
   }
   io_close_tty_line ();
   if (OPTION_TRACE (&A68G_JOB)) {
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "genie: frame stack %uk, expression stack %uk, heap %uk, handles %uk\n", A68G (frame_stack_size) / KILOBYTE, A68G (expr_stack_size) / KILOBYTE, A68G (heap_size) / KILOBYTE, A68G (handle_pool_size) / KILOBYTE) >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "genie: frame stack %uk, expression stack %uk, heap %uk, handles %uk\n", A68G (frame_stack_size) / A68G_KILO, A68G (expr_stack_size) / A68G_KILO, A68G (heap_size) / A68G_KILO, A68G (handle_pool_size) / A68G_KILO) >= 0);
     WRITE (A68G_STDOUT, A68G (output_line));
   }
   install_signal_handlers ();
   set_default_event_procedure (&A68G (on_gc_event));
   A68G (do_confirm_exit) = A68G_TRUE;
-#if defined (BUILD_PARALLEL_CLAUSE)
-  ASSERT (pthread_mutex_init (&A68G_PAR (unit_sema), NULL) == 0);
-#endif
+  #if defined (BUILD_PARALLEL_CLAUSE)
+    ASSERT (pthread_mutex_init (&A68G_PAR (unit_sema), NULL) == 0);
+  #endif
 // Dive into the program.
   if (setjmp (A68G (genie_exit_label)) == 0) {
     NODE_T *p = SUB (TOP_NODE (&A68G_JOB));
@@ -411,9 +411,9 @@ void genie (void *compile_plugin)
 // Here we go ...
     A68G (in_execution) = A68G_TRUE;
     A68G (f_entry) = TOP_NODE (&A68G_JOB);
-#if defined (BUILD_UNIX)
-    (void) a68g_alarm (INTERRUPT_INTERVAL);
-#endif
+    #if defined (BUILD_UNIX)
+      (void) a68g_alarm (INTERRUPT_INTERVAL);
+    #endif
     if (OPTION_TRACE (&A68G_JOB)) {
       WIS (TOP_NODE (&A68G_JOB));
     }
@@ -589,47 +589,6 @@ void genie_check_initialisation (NODE_T * p, BYTE_T * w, MOID_T * q)
       CHECK_INIT (p, INITIALISED (i), q);
       return;
     }
-#if (A68G_LEVEL >= 3)
-  case MODE_LONG_INT:
-  case MODE_LONG_REAL:
-  case MODE_LONG_BITS: {
-      A68G_DOUBLE *z = (A68G_DOUBLE *) w;
-      CHECK_INIT (p, INITIALISED (z), q);
-      return;
-    }
-  case MODE_LONG_COMPLEX: {
-      A68G_LONG_REAL *r = (A68G_LONG_REAL *) w;
-      A68G_LONG_REAL *i = (A68G_LONG_REAL *) (w + SIZE_ALIGNED (A68G_LONG_REAL));
-      CHECK_INIT (p, INITIALISED (r), q);
-      CHECK_INIT (p, INITIALISED (i), q);
-      return;
-    }
-  case MODE_LONG_LONG_INT:
-  case MODE_LONG_LONG_REAL:
-  case MODE_LONG_LONG_BITS: {
-      MP_T *z = (MP_T *) w;
-      CHECK_INIT (p, (unt) MP_STATUS (z) & INIT_MASK, q);
-      return;
-    }
-#else
-  case MODE_LONG_INT:
-  case MODE_LONG_LONG_INT:
-  case MODE_LONG_REAL:
-  case MODE_LONG_LONG_REAL:
-  case MODE_LONG_BITS:
-  case MODE_LONG_LONG_BITS: {
-      MP_T *z = (MP_T *) w;
-      CHECK_INIT (p, (unt) MP_STATUS (z) & INIT_MASK, q);
-      return;
-    }
-  case MODE_LONG_COMPLEX: {
-      MP_T *r = (MP_T *) w;
-      MP_T *i = (MP_T *) (w + size_mp ());
-      CHECK_INIT (p, (unt) r[0] & INIT_MASK, q);
-      CHECK_INIT (p, (unt) i[0] & INIT_MASK, q);
-      return;
-    }
-#endif
   case MODE_LONG_LONG_COMPLEX: {
       MP_T *r = (MP_T *) w;
       MP_T *i = (MP_T *) (w + size_long_mp ());
@@ -686,6 +645,47 @@ void genie_check_initialisation (NODE_T * p, BYTE_T * w, MOID_T * q)
       CHECK_INIT (p, INITIALISED (z), q);
       return;
     }
+  #if (A68G_LEVEL >= 3)
+    case MODE_LONG_INT:
+    case MODE_LONG_REAL:
+    case MODE_LONG_BITS: {
+        A68G_DOUBLE *z = (A68G_DOUBLE *) w;
+        CHECK_INIT (p, INITIALISED (z), q);
+        return;
+      }
+    case MODE_LONG_COMPLEX: {
+        A68G_LONG_REAL *r = (A68G_LONG_REAL *) w;
+        A68G_LONG_REAL *i = (A68G_LONG_REAL *) (w + SIZE_ALIGNED (A68G_LONG_REAL));
+        CHECK_INIT (p, INITIALISED (r), q);
+        CHECK_INIT (p, INITIALISED (i), q);
+        return;
+      }
+    case MODE_LONG_LONG_INT:
+    case MODE_LONG_LONG_REAL:
+    case MODE_LONG_LONG_BITS: {
+        MP_T *z = (MP_T *) w;
+        CHECK_INIT (p, (unt) MP_STATUS (z) & INIT_MASK, q);
+        return;
+      }
+  #else
+    case MODE_LONG_INT:
+    case MODE_LONG_LONG_INT:
+    case MODE_LONG_REAL:
+    case MODE_LONG_LONG_REAL:
+    case MODE_LONG_BITS:
+    case MODE_LONG_LONG_BITS: {
+        MP_T *z = (MP_T *) w;
+        CHECK_INIT (p, (unt) MP_STATUS (z) & INIT_MASK, q);
+        return;
+      }
+    case MODE_LONG_COMPLEX: {
+        MP_T *r = (MP_T *) w;
+        MP_T *i = (MP_T *) (w + size_mp ());
+        CHECK_INIT (p, (unt) r[0] & INIT_MASK, q);
+        CHECK_INIT (p, (unt) i[0] & INIT_MASK, q);
+        return;
+      }
+  #endif
   }
 }
 
@@ -804,11 +804,11 @@ char *propagator_name (PROP_PROC * p)
   if (p == genie_or_function) {
     return "genie_or_function";
   }
-#if defined (BUILD_PARALLEL_CLAUSE)
-  if (p == genie_parallel) {
-    return "genie_parallel";
-  }
-#endif
+  #if defined (BUILD_PARALLEL_CLAUSE)
+    if (p == genie_parallel) {
+      return "genie_parallel";
+    }
+  #endif
   if (p == genie_routine_text) {
     return "genie_routine_text";
   }
