@@ -4,7 +4,7 @@
 //! @section Copyright
 //
 // This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
+// Copyright 2001-2025 J. Marcel van der Veer <algol68g@xs4all.nl>.
 //
 //! @section License
 //
@@ -36,6 +36,7 @@
 
 #undef HAVE_GNU_MPFR
 #undef HAVE_CURSES
+#undef HAVE_RTLIB
 
 #define HAVE_QUADMATH_H
 #define HAVE_REGEX_H
@@ -86,6 +87,7 @@
 #define HAVE_FLOAT_H
 #define HAVE_LIBGEN_H
 #define HAVE_LIMITS_H
+#define HAVE_MALLOC_H
 #define HAVE_MATH_H
 #define HAVE_SETJMP_H
 #define HAVE_SIGNAL_H
@@ -114,11 +116,11 @@
 #define PACKAGE_BUGREPORT "Marcel van der Veer <algol68g@xs4all.nl>"
 
 // Define to the full name and version of this package.
-#define PACKAGE_STRING "algol68g 3.8.0"
+#define PACKAGE_STRING "algol68g 3.9.10"
 
 // Define to the version of this package.
-#define PACKAGE_VERSION "3.8.0"
+#define PACKAGE_VERSION "3.9.10"
 
 // Version number of package
-#define VERSION "3.8.0"
+#define VERSION "3.9.10"
 
