@@ -30,21 +30,21 @@
 
 // Memory sizes are in SI units.
 
-#define KILOBYTE ((size_t) 1000)
-#define MEGABYTE (KILOBYTE * KILOBYTE)
-#define GIGABYTE (KILOBYTE * MEGABYTE)
+#define A68G_KILO ((size_t) 1000)
+#define A68G_MEGA (A68G_KILO * A68G_KILO)
+#define A68G_GIGA (A68G_KILO * A68G_MEGA)
 #if defined (HAVE_LARGE_STORAGE) && (A68G_LEVEL >= 3)
-  #define TERABYTE (KILOBYTE * GIGABYTE)
-  #define PETABYTE (KILOBYTE * TERABYTE)
+  #define A68G_TERA (A68G_KILO * A68G_GIGA)
+  #define A68G_PETA (A68G_KILO * A68G_TERA)
 #endif
 
 #if defined (HAVE_LARGE_STORAGE)
-  #define MAX_MEM_SIZE ((size_t) 2 * TERABYTE)
+  #define MAX_MEM_SIZE ((size_t) 2 * A68G_TERA)
 #else
-  #define MAX_MEM_SIZE ((size_t) 2 * GIGABYTE)
+  #define MAX_MEM_SIZE ((size_t) 2 * A68G_GIGA)
 #endif
 
-#define MEM_OVERHEAD ((size_t) MEGABYTE)
+#define MEM_OVERHEAD ((size_t) A68G_MEGA)
 
 #define A68G_TRUE ((BOOL_T) 1)
 #define A68G_FALSE ((BOOL_T) 0)
@@ -94,12 +94,12 @@
 #define A68G_DIR ".a68g"
 #define A68G_HISTORY_FILE ".a68g.edit.hist"
 #define A68G_MAX_LEX_LEVEL (INT_MAX)
-#define A68G_NO_FILE ((FILE_T) -1)
+#define A68G_NO_FILE ((FILE_T) (-1))
 #define A68G_PROTECTION (S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)  // -rw-r--r--
 #define A68G_READ_ACCESS (O_RDONLY)
-#define A68G_WRITE_ACCESS (O_WRONLY | O_CREAT | O_TRUNC)
-#define BUFFER_SIZE (KILOBYTE)
-#define DEFAULT_WIDTH (-1)
+#define A68G_WRITE_ACCESS (O_WRONLY)
+#define BUFFER_SIZE (A68G_KILO)
+#define DEFAULT_WIDTH ((size_t) (-1))
 
 #define EMBEDDED_FORMAT A68G_TRUE
 #define EVEN(k) ((k) % 2 == 0)
@@ -131,7 +131,7 @@
 
 // Macros
 
-#define _SKIP_ { (void) 0;}
+#define _SKIP_ {(void) 0;}
 
 #define BUFCLR(z) {a68g_bufset ((z), 0, BUFFER_SIZE + 1);}
 
@@ -168,10 +168,17 @@
    INT_T _m_k = (INT_T) (n); A68G_ALIGN_T *_m_u = (A68G_ALIGN_T *) (d), _m_v = (A68G_ALIGN_T) (s);\
    while (_m_k > 0) {*_m_u++ = _m_v; _m_k -= A68G_ALIGNMENT;}}
 
-#define ABEND(p, reason, info) {\
-  if (p) {\
-    abend ((char *) reason, (char *) info, __FILE__, __LINE__);\
-  }}
+#if defined (A68G_DEBUG)
+  #define ABEND(p, reason, info) {\
+    if (p) {\
+      abend ((char *) reason, (char *) info, (char *) __func__);\
+    }}
+#else
+  #define ABEND(p, reason, info) {\
+    if (p) {\
+      abend ((char *) reason, (char *) info, NO_TEXT);\
+    }}
+#endif
 
 #if defined (HAVE_CURSES)
 #define ASSERT(f) {\
@@ -251,6 +258,7 @@
 #define ADDR(p) ((p)->addr)
 #define ANNOTATION(p) ((p)->annotation)
 #define ANONYMOUS(p) ((p)->anonymous)
+#define APPEND(p) ((p)->append)
 #define APPLICATIONS(p) ((p)->applications)
 #define AP_INCREMENT(p) ((p)->ap_increment)
 #define ARGSIZE(p) ((p)->argsize)
