@@ -103,9 +103,9 @@ struct ACTIVATION_RECORD
   int frame_no, frame_level, parameter_level;
   jmp_buf *jump_stat;
   NODE_T *node;
-#if defined (BUILD_PARALLEL_CLAUSE)
-  pthread_t thread_id;
-#endif
+  #if defined (BUILD_PARALLEL_CLAUSE)
+    pthread_t thread_id;
+  #endif
 };
 
 struct PROP_T
@@ -473,28 +473,28 @@ struct A68G_FILE
   A68G_PROCEDURE file_end_mended, page_end_mended, line_end_mended, value_error_mended, open_error_mended, transput_error_mended, format_end_mended, format_error_mended;
   A68G_REF identification, terminator, string;
   ADDR_T frame_pointer, stack_pointer;  // Since formats open frames
-  BOOL_T read_mood, write_mood, char_mood, draw_mood, opened, open_exclusive, end_of_file, tmp_file;
+  BOOL_T read_mood, write_mood, char_mood, draw_mood, opened, append, open_exclusive, end_of_file, tmp_file;
   FILE_T fd;
   int transput_buffer, strpos, file_entry;
   struct
   {
     FILE *stream;
-#if defined (HAVE_GNU_PLOTUTILS)
-    plPlotter *plotter;
-    plPlotterParams *plotter_params;
-#endif
+    #if defined (HAVE_GNU_PLOTUTILS)
+      plPlotter *plotter;
+      plPlotterParams *plotter_params;
+    #endif
     BOOL_T device_made, device_opened;
     A68G_REF device, page_size;
     int device_handle /* deprecated */ , window_x_size, window_y_size;
     REAL_T x_coord, y_coord, red, green, blue;
   }
   device;
-#if defined (HAVE_POSTGRESQL)
-  #if ! defined (A68G_OPTIMISE)
-    PGconn *connection;
-    PGresult *result;
+  #if defined (HAVE_POSTGRESQL)
+    #if ! defined (A68G_OPTIMISE)
+      PGconn *connection;
+      PGresult *result;
+    #endif
   #endif
-#endif
 };
 
 #define M_BITS (MODE (BITS))
