@@ -144,14 +144,14 @@ void a68g_exit (int);
 void a68g_free (void *);
 void a68g_getty (int *, int *);
 void a68g_rm (char *);
-void abend (char *, char *, char *, int);
+void abend (char *, char *, char *);
 void announce_phase (char *);
 void apropos (FILE_T, char *, char *);
 void default_mem_sizes (INT_T, LINE_T *, char *);
 void discard_heap (void);
 void free_file_entries (void);
 void free_syntax_tree (NODE_T *);
-void get_stack_size (void);
+void get_C_stack_size (void);
 void indenter (MODULE_T *);
 void init_curses (void);
 void init_file_entries (void);
